@@ -1,6 +1,6 @@
 \donttest{
 # Load Gorilla data
-data("gorillas")
+data("gorillas", package = "inlabru")
 
 # Plot mesh using default edge colors
 
