@@ -1,7 +1,7 @@
 \donttest{
 # Load Gorilla data
 
-data("gorillas")
+data("gorillas", package = "inlabru")
 
 # Plot Gorilla elevation covariate provided as SpatialPixelsDataFrame. 
 # The same syntax applies to SpatialGridDataFrame objects.
